import 'package:flutter/material.dart';
import 'package:og1_post/src/widgets/_widgets.dart';
import 'package:og1_system/og1_system.dart';

/// Populated from single UserModel instance and list of TextButtons.
/// Consists of Og1NewPostEdit and Og1UserActions
class Og1NewPost extends StatelessWidget {
  final UserModel currentUser;
  final List<TextButton>? actionButtons;

  const Og1NewPost({Key? key, required this.currentUser, this.actionButtons})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return ResponsiveBuilder(builder: (context, sizingInformation) {
      EdgeInsets margin = const EdgeInsets.symmetric(horizontal: 0.0);
      double elevation = 0.0;
      ShapeBorder? shape;

      if (sizingInformation.deviceScreenType == DeviceScreenType.desktop) {
        margin = const EdgeInsets.symmetric(horizontal: 5.0);
        elevation = 1.0;
        shape =
            RoundedRectangleBorder(borderRadius: BorderRadius.circular(10.0));
      }

      return Card(
          margin: margin,
          elevation: elevation,
          shape: shape,
          child: Container(
              padding: const EdgeInsets.fromLTRB(
                12.0,
                8.0,
                12.0,
                0.0,
              ),
              color: Theme.of(context).cardColor,
              child: Column(children: [
                Og1NewPostEdit(currentUser: currentUser),
                const Divider(height: 10.0, thickness: 0.5),
                Og1UserActions(actionButtons: actionButtons)
              ])));
    });
  }
}
