import 'package:flutter/material.dart';
import 'package:og1_post/src/models/_models.dart';
import 'package:og1_system/og1_system.dart';

import '../_widgets.dart';

/// Populated from single PostModel instance.
/// Consists of Post Header, PostCaption, (optional) PostPhoto and PostStats
class Og1Post extends StatelessWidget {
  final PostModel post;
  final List<Og1PostButton>? postActionButtons;

  const Og1Post({Key? key, required this.post, this.postActionButtons})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return ResponsiveBuilder(builder: (context, sizingInformation) {
      EdgeInsets margin = const EdgeInsets.symmetric(horizontal: 0.0);
      double elevation = 0.0;
      ShapeBorder? shape;

      if (sizingInformation.deviceScreenType == DeviceScreenType.desktop) {
        margin = const EdgeInsets.symmetric(horizontal: 5.0);
        elevation = 1.0;
        shape =
            RoundedRectangleBorder(borderRadius: BorderRadius.circular(10.0));
      }
      return Card(
        margin: margin,
        elevation: elevation,
        shape: shape,
        child: Container(
          color: Theme.of(context).cardColor,
          padding: const EdgeInsets.symmetric(vertical: 8.0),
          child: Column(
            children: [
              Padding(
                padding: const EdgeInsets.symmetric(horizontal: 12.0),
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.stretch,
                  children: [
                    Og1PostHeader(
                      post: post,
                    ),
                    const SizedBox(height: 8.0),
                    Text(post.caption),
                  ],
                ),
              ),
              if (post.imageUrl != null) ...[
                const SizedBox(height: 10.0),
                Og1PostPhoto(
                  postImageUrl: post.imageUrl,
                ),
              ],
              Og1PostStats(post: post, postActionButtons: postActionButtons),
            ],
          ),
        ),
      );
    });
  }
}
