import 'package:carousel_slider/carousel_slider.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:og1_ui/og1_ui.dart';

/// Populated from optional list of postImageUrl(s)
/// Consists of an image, or CarouselSlider of images
class Og1PostPhoto extends StatelessWidget {
  final List<String>? postImageUrl;

  const Og1PostPhoto({
    Key? key,
    required this.postImageUrl,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    if (postImageUrl!.length == 1) {
      return Padding(
        padding: const EdgeInsets.symmetric(vertical: 8.0),
        child: CachedNetworkImage(
          imageUrl: postImageUrl![0],
        ),
      );
    }

    return Padding(
      padding: const EdgeInsets.symmetric(vertical: 8.0),
      child: Container(
        width: double.infinity,
        margin: const EdgeInsets.symmetric(horizontal: 10.0),
        child: ScrollConfiguration(
            behavior: ScrollConfiguration.of(context).copyWith(
              dragDevices: {
                PointerDeviceKind.touch,
                PointerDeviceKind.mouse,
              },
            ),
            child: CarouselSlider.builder(
              itemCount: postImageUrl!.length,
              options: CarouselOptions(
                enlargeCenterPage: true,
                enableInfiniteScroll: false,
                pageViewKey: const PageStorageKey<String>('carousel_slider'),
              ),
              itemBuilder: (context, index, realIndex) {
                return CachedNetworkImage(
                  imageUrl: postImageUrl![index],
                  fit: BoxFit.cover,
                  width: double.infinity,
                );
              },
            )),
      ),
    );
  }
}
